{ config, pkgs, lib, ... }:

{
  imports = [
    <nixpkgs/nixos/modules/profiles/minimal.nix>
    ../../lib/hq.nix
    ../../lib/emery.nix
    ./containers
    ./hardware-configuration.nix
    ./hydra.nix
    ./nix-serve.nix
  ];

  security.sudo.wheelNeedsPassword = false;
  services.openssh = {
    enable = true;
    passwordAuthentication = false;
    # DO NOT CHANGE, KINDERGARTEN IS OVER
  };

  programs.mosh.enable = true;

  nix = {
    package = pkgs.nixFlakes;
    extraOptions = "experimental-features = nix-command flakes";
    gc.automatic = true;
    trustedUsers = [ "root" ];
    buildMachines = [{
      hostName = "hydra.hq.c3d2.de";
      system = "x86_64-linux";
      maxJobs = 2;
    }];
  };

  networking = {
    firewall.enable = false;
    hostName = "server7";
    useDHCP = false;
    bridges.br0.interfaces = [ "enp2s0f0" ];
    interfaces = {
      br0 = {
        useDHCP = true;
        preferTempAddress = false;
        ipv4.addresses = [{
          address = "172.22.99.245";
          prefixLength = 24;
        }];
      };
      enp2s0f1.useDHCP = false;
    };
  };
  hq.yggdrasil = {
    enable = true;
    interface = "br0";
  };
  
  environment.systemPackages = with pkgs; [ tmux htop vim gitMinimal nixfmt ];

  services.collectd = {
    enable = true;
    autoLoadPlugin = true;
    extraConfig = ''
      HostName "${config.networking.hostName}"
      FQDNLookup false
      Interval 10

      LoadPlugin sensors
      LoadPlugin memory
      LoadPlugin irq
      LoadPlugin thermal
      LoadPlugin processes
      LoadPlugin disk
      LoadPlugin hddtemp
      LoadPlugin df
      LoadPlugin cpu
      LoadPlugin cpufreq
      LoadPlugin entropy
      LoadPlugin load
      LoadPlugin swap
      LoadPlugin cgroups
      LoadPlugin vmem
      LoadPlugin interface
      LoadPlugin network
      <Plugin "network">
        Server "grafana.hq.c3d2.de" "25826"
      </Plugin>
    '';
  };

  boot.tmpOnTmpfs = true;

  # Use the systemd-boot EFI boot loader.
  boot.loader = {
    systemd-boot.enable = true;
    efi.canTouchEfiVariables = true;
  };

  time.timeZone = "Europe/Berlin";

  system.stateVersion = "19.09"; # Did you read the comment?
}
